#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec-vm
Version:	4.1.17
Release:	1%{dist}
Summary:	The Qubes qrexec files (qube side)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:	pam-devel
BuildRequires:	pandoc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-core-qrexec-devel
BuildRequires:	lsb-core-noarch
BuildRequires:	systemd-devel

Requires:   python%{python3_pkgversion}
Requires:   qubes-core-qrexec = %{version}-%{release}

Provides:   qubes-core-agent-qrexec = 4.1.0-1
Obsoletes:  qubes-core-agent-qrexec < 4.1.0-1

Source0: qubes-core-qrexec-%{version}.tar.gz

%description
The Qubes qrexec files for installation on a qube.

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
make all-vm
#make -C doc PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} man

%install
make install-vm \
    DESTDIR=$RPM_BUILD_ROOT \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    SYSCONFDIR=%{_sysconfdir}

#make -C doc DESTDIR=$RPM_BUILD_ROOT \
#    PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} \
#    install

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%post
%systemd_post qubes-qrexec-agent.service

%preun
%systemd_preun qubes-qrexec-agent.service

%posttrans
# when upgrading from R4.0, %%postun of qubes-core-agent-qrexec will revert
# %%post of this package. Redo the action in %%posttrans
%systemd_post qubes-qrexec-agent.service
# and then start it back
if systemctl is-enabled qubes-qrexec-agent.service >/dev/null 2>&1; then
    systemctl start qubes-qrexec-agent.service
fi

%files
%defattr(-,root,root,-)
%config(noreplace) /etc/pam.d/qrexec
%dir /etc/qubes/rpc-config
/etc/qubes/rpc-config/README

%{_bindir}/qrexec-client-vm
%{_bindir}/qrexec-fork-server

%{_mandir}/man1/qrexec-client-vm.1*

/usr/lib/qubes/qrexec-agent
/usr/lib/qubes/qrexec-client-vm
/usr/lib/qubes/qrexec_client_vm
/lib/systemd/system/qubes-qrexec-agent.service

%changelog
* Fri Feb 18 2022 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec.git

* Fri Feb 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7f910aa
- version 4.1.17

* Tue Feb 15 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6c78dc3
- policy: fix notification on refused autostart

* Fri Jan 14 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c8e83f9
- Fix error return value in allocate_vchan_port

* Fri Dec 17 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ebdc43b
- version 4.1.16

* Thu Dec 16 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5014923
- policy: fix reporting failed target start

* Tue Dec 14 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - a668ac1
- Check the return value of snprintf

* Sun Aug 22 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 339f79a
- Add assertions that FD_SETSIZE is not exceeded

* Thu Jul 01 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 12e0092
- version 4.1.15

* Wed Jun 30 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0516ffc
- Fix FD leak causing DispVMs not being cleaned up properly

* Fri Jun 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bf76f79
- version 4.1.14

* Thu Jun 17 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f7d510b
- Force color pytest output in gitlab

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 4fc2578
- Add a test for qrexec policy allowing an operation

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 46f57e8
- Parse the qrexec call metadata before untrusted data

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 3ba64f3
- Avoid calling get_system_info() twice

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 4276035
- Automatically install dependencies when possible

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 831208f
- Handle partial reads from StreamReader.read

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0b2332f
- Set socket modes properly

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 61d603c
- Shut up pylint

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - dcff4f7
- Lots of unit tests and some bug fixes

* Sat May 22 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 121aff1
- Use separate sockets for different services

* Sat May 22 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - c1d8dd9
- Do not use the asynctest module

* Sat May 22 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 93190cf
- Add policy.EvalGUI service

* Fri May 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 587dac3
- Create a DispVMTemplate instance when needed

* Fri May 21 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2f0d37a
- Use generic 'guivm' service to tell if running inside GUI VM

* Fri May 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0d79f74
- Tell pylint not to whine about extra parentheses

* Fri May 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - adb1301
- Add unit tests for policy.EvalSimple

* Fri May 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - e08a112
- Add a policy.EvalSimple qrexec service

* Thu May 20 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - cbab1fc
- Switch from __gcov_flush to __gcov_dump + __gcov_reset

* Mon May 17 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 46dc9c1
- Be stricter about command-line parsing

* Thu Mar 04 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c636c53
- daemon: fix checking qrexec-policy-daemon response

* Thu Mar 04 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - afea444
- Adjust vchan_{send,recv} error checking

* Wed Jan 27 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - fdd306f
- winusb: check if pam include file exists and set appropriate flags

* Wed Jan 27 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - 2ce1a34
- winsub: fix broad exception

* Thu Jan 21 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - 4c5ba18
- winusb: append LDLIBS

* Tue Jan 19 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - dbb6b51
- winusb: set guivm to None on unknown source

* Tue Jan 19 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - ef92037
- winusb: allow to build without pam

* Sun Jan 10 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7d75d31
- version 4.1.13

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 41e36f7
- agent: do not interrupt established connections on restart

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ed34dc7
- version 4.1.12

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7e4e562
- debian: update compat

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7f35ef8
- debian: update control

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 463ce10
- pylint: temporarily disable unsubscriptable-object - buggy with py3.9

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 863242c
- gitlab-ci: include custom jobs

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f748160
- Allow to override vchan variant selection with BACKEND_VMM variable

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 031a321
- Add .gitlab-ci.yml

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c86360f
- Use pkg-config to get BACKEND_VMM

* Fri Nov 13 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c69202b
- Set default BACKEND_VMM value to xen

* Fri Nov 13 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aecd3e2
- version 4.1.11

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b98078a
- Start qrexec-agent only after systemd let in normal users

* Wed Nov 11 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd9df7e
- qrexec-policy-agent: do not patch event loop on module import

